skhubness.neighbors.NearestCentroid
===================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: NearestCentroid

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NearestCentroid.__init__
      ~NearestCentroid.fit
      ~NearestCentroid.get_params
      ~NearestCentroid.predict
      ~NearestCentroid.score
      ~NearestCentroid.set_params
   
   

   
   
   